@@ -21,13 +21,13 @@ class Config:
     random_investors: int
     error_sleep_time_sec: int
     storage_bucket: str
-    other: field(default_factory=dict)
     total_loss_threshold: float = -2000
-    update_candidate_tickers_in_sec: int = 60 * 3 # 3 minutes
+    update_candidate_tickers_in_sec: int = 60 * 3  # 3 minutes
     max_order_wait_attempts: int = 50
     dirs: Dict[str, str] = field(default_factory=dict)
     queues: Dict[str, str] = field(default_factory=dict)
     urls: Dict[str, str] = field(default_factory=dict)
+    other: Dict[str, str] = field(default_factory=dict)
 
     @classmethod
     def deserialize(cls, input_data: Dict[str, Any]) -> Config:
