@@ -8,6 +8,8 @@ class ConfigUrlType(Enum):
     ACCOUNTS = auto()
     CANDLES = auto()
     COINBASE = auto()
+    EXECUTOR = auto()
+    MANAGER = auto()
     ROBINHOOD = auto()
     RUSSELL = auto()
     STATS = auto()
