@@ -17,13 +17,3 @@ class Direction(Printable, Enum):
 
     def value(self) -> str:
         return self.name.lower()
-
-
-def main() -> None:
-    print(Direction.to_enum("down"))
-    print(Direction.to_enum("neutral"))
-    print(Direction.UP.value())
-
-
-if __name__ == "__main__":
-    main()
