@@ -3,7 +3,7 @@ from __future__ import annotations
 from copy import deepcopy
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Dict, Any
+from typing import Any, Dict
 
 from ctlml_commons.entity.execution_type import ExecutionType
 from ctlml_commons.util.date_utils import convert_dates, datetime_to_str
