@@ -1,11 +1,12 @@
 from __future__ import annotations
 
 from copy import deepcopy
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Tuple
 
 from ctlml_commons.util.date_utils import convert_dates
+from ctlml_commons.util.entity_utils import separate_fields
 
 
 @dataclass(frozen=True)
@@ -25,10 +26,17 @@ class News:
     related_instruments: List[str]
     preview_text: str
     currency_id: str
+    other: field(default_factory=dict)
 
     @classmethod
     def deserialize(cls, input_data: Dict[str, Any]) -> News:
-        return News(**cls.clean(input_data=input_data))
+        known, other = cls.separate(cls.clean(input_data=input_data))
+
+        return cls(**known, other=other)
+
+    @classmethod
+    def separate(cls, input_data: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
+        return separate_fields(known_fields=cls.__dataclass_fields__.keys(), input_data=input_data)
 
     @classmethod
     def clean(cls, input_data: Dict[str, Any]) -> Dict[str, Any]:
